######################
scikit-learn-extra API
######################

.. currentmodule:: sklearn_extra

Kernel approximation
====================

.. autosummary::
   :toctree: generated/
   :template: class.rst

   kernel_approximation.Fastfood

EigenPro
========

.. autosummary::
   :toctree: generated/
   :template: class.rst

   kernel_methods.EigenProRegressor
   kernel_methods.EigenProClassifier

Clustering
====================

.. autosummary::
   :toctree: generated/
   :template: class.rst

   cluster.KMedoids
   cluster.CommonNNClustering
   cluster.CLARA

Robust
====================

.. autosummary::
   :toctree: generated/
   :template: class.rst

   robust.RobustWeightedClassifier
   robust.RobustWeightedRegressor
   robust.RobustWeightedKMeans
